﻿using System.Collections.Generic;
using System.Collections.ObjectModel;

namespace Petzold.Phone.EBookReader
{
    public class Library
    {
        public Library()
        {
            this.Authors = new ObservableCollection<AuthorInfo>();
        }

        public ObservableCollection<AuthorInfo> Authors { protected set; get; }

        public void CreateLibraryEntry(int id, IList<string> titles, IList<string> creators)
        {
            int index;

            // Create AuthorInfo object from downloaded book
            AuthorInfo author = new AuthorInfo();
            foreach (string creator in creators)
                author.Creators.Add(creator);

            // Check if the library already contains that author
            if (this.Authors.Contains(author))
            {
                author = this.Authors[this.Authors.IndexOf(author)];
            }
            else
            {
                // Insert author alphabetically to author collection
                for (index = 0; index < this.Authors.Count; index++)
                {
                    if (author.CompareTo(this.Authors[index]) < 0)
                    {
                        this.Authors.Insert(index, author);
                        break;
                    }
                }
                if (index == this.Authors.Count)
                    this.Authors.Add(author);
            }

            // Create TitleInfo object from downloaded book
            TitleInfo titleInfo = new TitleInfo { ID = id };
            foreach (string title in titles)
                titleInfo.Titles.Add(title);

            // Insert title alphabetically to title collection
            for (index = 0; index < author.Titles.Count; index++)
            {
                if (titleInfo.CompareTo(author.Titles[index]) == 0)
                {
                    author.Titles[index] = titleInfo;
                    break;
                }
                else if (titleInfo.CompareTo(author.Titles[index]) < 0)
                {
                    author.Titles.Insert(index, titleInfo);
                    break;
                }
            }
            if (index == author.Titles.Count)
                author.Titles.Add(titleInfo);
        }

        public bool DoesLibraryEntryExist(int id)
        {
            foreach (AuthorInfo author in this.Authors)
                foreach (TitleInfo title in author.Titles)
                    if (title.ID == id)
                        return true;

            return false;
        }
    }
}
