﻿using System;
using System.Windows;
using System.Windows.Navigation;
using Microsoft.Phone.Controls;
using Petzold.Phone.EBookReader;
using PhreeBookReader.CatalogServiceReference;

namespace PhreeBookReader
{
    public partial class BookInformationPage : PhoneApplicationPage
    {
        BookInfo bookInfo;
        GutenbergBook gutenbergBook;

        public BookInformationPage()
        {
            InitializeComponent();
        }

        protected override void OnNavigatedTo(NavigationEventArgs e)
        {
            int bookID = Int32.Parse(this.NavigationContext.QueryString["bookid"]);
            gutenbergBook = GutenbergBookExtensions.Load(bookID);
            catalogInfo.GutenbergBook = gutenbergBook;

            bookInfo = BookInfo.Load(bookID);
            LayoutRoot.DataContext = bookInfo;

            // This is the case if invoked from BookViewerPage
            if (this.NavigationContext.QueryString.ContainsKey("doNotAllowDeletion"))
            {
                deleteButton.Visibility = Visibility.Collapsed;
            }

            base.OnNavigatedTo(e);
        }

        protected override void OnNavigatedFrom(NavigationEventArgs e)
        {
            // bookInfo will be null if the book has been deleted
            if (bookInfo != null)
            {
                bookInfo.Save();

                // Also, replace BookInfo in Bedside collection
                AppSettings appSettings = (Application.Current as App).AppSettings;
                if (appSettings.Bedside.Contains(bookInfo))
                {
                    int index = appSettings.Bedside.IndexOf(bookInfo);
                    appSettings.Bedside[index] = bookInfo;
                }
            }

            base.OnNavigatedFrom(e);
        }

        void OnChangeDisplayTitleClick(object sender, RoutedEventArgs args)
        {
            string uri = String.Format("/DisplayTitlePage.xaml?bookid={0}", bookInfo.ID);
            this.NavigationService.Navigate(new Uri(uri, UriKind.Relative));
        }

        void OnChapterBreaksClick(object sender, RoutedEventArgs args)
        {
            string uri = String.Format("/ChapterAnalysisPage.xaml?bookid={0}", bookInfo.ID);
            this.NavigationService.Navigate(new Uri(uri, UriKind.Relative));
        }

        void OnDeleteButtonClick(object sender, RoutedEventArgs args)
        {
            optionsButtons.IsEnabled = false;
            deleteConfirmationPanel.Visibility = Visibility.Visible;
            scrollViewer.ScrollToBottom();
        }

        void OnOkDeleteButtonClick(object sender, RoutedEventArgs args)
        {
            int deleteBookID = bookInfo.ID;

            // Delete the book, info file, and Gutenberg catalog file from isolated storage
            gutenbergBook.Delete(deleteBookID);
            bookInfo.Delete();

            // Delete the book from the library
            AppSettings appSettings = (Application.Current as App).AppSettings;
            Library library = appSettings.Library;
            bool foundID = false;

            for (int iAuthor = 0; iAuthor < library.Authors.Count; iAuthor++)
            {
                AuthorInfo author = library.Authors[iAuthor];

                for (int iTitle = 0; iTitle < author.Titles.Count; iTitle++)
                {
                    TitleInfo title = author.Titles[iTitle];

                    if (deleteBookID == title.ID)
                    {
                        author.Titles.RemoveAt(iTitle);

                        if (author.Titles.Count == 0)
                            library.Authors.RemoveAt(iAuthor);

                        foundID = true;
                        break;
                    }
                }
                if (foundID)
                    break;
            }

            // Delete the book from the bedside
            for (int iBook = 0; iBook < appSettings.Bedside.Count; iBook++)
            {
                BookInfo book = appSettings.Bedside[iBook];

                if (deleteBookID == book.ID)
                {
                    appSettings.Bedside.RemoveAt(iBook);
                    break;
                }
            }

            // Set the field to null and similarly in App
            bookInfo = null;

            // Go back to the main page
            this.NavigationService.GoBack();
        }

        void OnCancelDeleteButtonClick(object sender, RoutedEventArgs args)
        {
            deleteConfirmationPanel.Visibility = Visibility.Collapsed;
            optionsButtons.IsEnabled = true;
        }
    }
}