﻿using System;
using System.Globalization;
using System.Windows;
using System.Windows.Controls;
using PhreeBookReader.CatalogServiceReference;

namespace PhreeBookReader
{
    public partial class CatalogInfoControl : UserControl
    {
        public static readonly DependencyProperty GutenbergBookProperty =
            DependencyProperty.Register("GutenbergBook",
                typeof(GutenbergBook),
                typeof(CatalogInfoControl),
                new PropertyMetadata(OnGutenbergBookChanged));

        public CatalogInfoControl()
        {
            InitializeComponent();
        }

        public GutenbergBook GutenbergBook
        {
            set { SetValue(GutenbergBookProperty, value); }
            get { return (GutenbergBook)GetValue(GutenbergBookProperty); }
        }

        static void OnGutenbergBookChanged(DependencyObject obj, DependencyPropertyChangedEventArgs args)
        {
            (obj as CatalogInfoControl).OnGutenbergBookChanged(args);
        }

        void OnGutenbergBookChanged(DependencyPropertyChangedEventArgs args)
        {
            GutenbergBook gutenbergBook = args.NewValue as GutenbergBook;
            this.DataContext = gutenbergBook;

            if (args.NewValue != null)
            {
                languageText.Text = new CultureInfo(gutenbergBook.Language).EnglishName;
                kilobyteSize.Text = (gutenbergBook.FileSize / 1024).ToString("N0");
                wordLength.Text = (1000 * (gutenbergBook.FileSize / 6000)).ToString("N0");
            }
        }
    }
}
