﻿using System;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Navigation;
using Microsoft.Phone.Controls;
using Petzold.Phone.EBookReader;

namespace PhreeBookReader
{
    public partial class ChapterAnalysisPage : PhoneApplicationPage
    {
        BookInfo bookInfo;
        bool anyChanges = false;

        public ChapterAnalysisPage()
        {
            InitializeComponent();
        }

        // Load BookInfo from file
        protected override void OnNavigatedTo(NavigationEventArgs args)
        {
            int bookID = Int32.Parse(this.NavigationContext.QueryString["bookid"]);
            bookInfo = BookInfo.Load(bookID);
            
            chaptersItemsControl.ItemsSource = bookInfo.Chapters;
            UpdateTextAndButtons();

            base.OnNavigatedTo(args);
        }

        // Save altered BookInfo to file (nothing more needs to be tombstoned)
        protected override void OnNavigatedFrom(NavigationEventArgs args)
        {
            if (anyChanges)
            {
                bookInfo.IsChapterAndPageInvalid = true;
                bookInfo.UpdateBookmarksAndAnnotations();
                bookInfo.Save();
            }
            base.OnNavigatedFrom(args);
        }

        void UpdateTextAndButtons()
        {
            numBlanks.Text = bookInfo.BlankLinesBetweenChapters.ToString();
            numChapters.Text = (bookInfo.Chapters.Count - 1).ToString();

            fewerButton.IsEnabled = bookInfo.BlankLinesBetweenChapters < 6;
            moreButton.IsEnabled = bookInfo.BlankLinesBetweenChapters > 2;
        }

        void OnFewerButtonClick(object sender, RoutedEventArgs args)
        {
            bookInfo.BlankLinesBetweenChapters += 1;
            bookInfo.GenerateChapters();
            UpdateTextAndButtons();
            anyChanges = true;
        }

        void OnMoreButtonClick(object sender, RoutedEventArgs args)
        {
            bookInfo.BlankLinesBetweenChapters -= 1;
            bookInfo.GenerateChapters();
            UpdateTextAndButtons();
            anyChanges = true;
        }

        void OnResetButtonClick(object sender, RoutedEventArgs args)
        {
            bookInfo.GenerateChapters();
            UpdateTextAndButtons();
            resetButton.IsEnabled = false;
            anyChanges = true;
        }

        void OnDeleteButtonClick(object sender, RoutedEventArgs args)
        {
            // Get the chapter to be deleted
            ChapterInfo chapter = (sender as Button).DataContext as ChapterInfo;
            int index = bookInfo.Chapters.IndexOf(chapter);

            // Add it's paragraph count to the count of the preceding chapter
            bookInfo.Chapters[index - 1].ParagraphCount += chapter.ParagraphCount;

            // Remove that chapter from the collection
            bookInfo.Chapters.Remove(chapter);

            // Update buttons, etc.
            UpdateTextAndButtons();
            resetButton.IsEnabled = true;
            anyChanges = true;
        }
    }
}