﻿using System.IO;
using System.IO.IsolatedStorage;
using System.Xml.Serialization;
using PhreeBookReader.CatalogServiceReference;

namespace PhreeBookReader
{
    public static class GutenbergBookExtensions
    {
        static string GetFilename(int bookID)
        {
            return bookID.ToString() + ".cat";
        }

        public static GutenbergBook Load(int bookID)
        {
            string filename = GutenbergBookExtensions.GetFilename(bookID);
            GutenbergBook gutenbergBook = null;

            using (IsolatedStorageFile storage = IsolatedStorageFile.GetUserStoreForApplication())
            {
                if (storage.FileExists(filename))
                {
                    using (IsolatedStorageFileStream stream = storage.OpenFile(filename, FileMode.Open, FileAccess.Read, FileShare.Read))
                    {
                        XmlSerializer serializer = new XmlSerializer(typeof(GutenbergBook));
                        gutenbergBook = serializer.Deserialize(stream) as GutenbergBook;
                    }
                }
            }
            return gutenbergBook;
        }

        public static void Save(this GutenbergBook gutenbergBook)
        {
            string filename = GutenbergBookExtensions.GetFilename(gutenbergBook.ID);

            using (IsolatedStorageFile storage = IsolatedStorageFile.GetUserStoreForApplication())
            {
                using (IsolatedStorageFileStream stream = storage.OpenFile(filename, FileMode.Create, FileAccess.Write))
                {
                    XmlSerializer serializer = new XmlSerializer(typeof(GutenbergBook));
                    serializer.Serialize(stream, gutenbergBook);
                }
            }
        }

        public static void Delete(this GutenbergBook gutenbergBook, int bookID)
        {
            string filename = GutenbergBookExtensions.GetFilename(bookID);

            using (IsolatedStorageFile storage = IsolatedStorageFile.GetUserStoreForApplication())
            {
                if (storage.FileExists(filename))
                    storage.DeleteFile(filename);
            }
        }
    }
}
