﻿using System;
using System.Collections.Generic;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Input;
using Microsoft.Phone.Shell;
using Petzold.Phone.EBookReader;
using PhreeBookReader.CatalogServiceReference;

namespace PhreeBookReader
{
    public partial class RequestControl : UserControl, ITombstonable
    {
        CatalogServiceClient proxy = new CatalogServiceClient();
        int bookID;

        public RequestControl()
        {
            InitializeComponent();
            proxy.BookInfoCompleted += OnCatalogServiceProxyBookInfoCompleted;
        }

        // ITombstonable method, called from MainPage
        public void SaveState(string prefix, IDictionary<string, object> state)
        {
            StateDictionaryHelper.SafeAdd(state, prefix + "bookIdText", bookIdTextBox.Text);
            StateDictionaryHelper.SafeAdd(state, prefix + "statusText", statusTextBlock.Text);
            StateDictionaryHelper.SafeAdd(state, prefix + "resultsVisibility", resultsPanel.Visibility);
            StateDictionaryHelper.SafeAdd(state, prefix + "gutenbergBook", catalogInfo.GutenbergBook);
        }

        // ITombstonable method, called from MainPage
        public void RestoreState(string prefix, IDictionary<string, object> state)
        {
            bookIdTextBox.Text = StateDictionaryHelper.SafeGet(state, prefix + "bookIdText", "");
            statusTextBlock.Text = StateDictionaryHelper.SafeGet<string>(state, prefix + "statusText", null);
            resultsPanel.Visibility = StateDictionaryHelper.SafeGet(state, prefix + "resultsVisibility", Visibility.Collapsed);
            catalogInfo.GutenbergBook = StateDictionaryHelper.SafeGet<GutenbergBook>(state, prefix + "gutenbergBook", null);
        }

        void OnBookIdTextBoxTextChanged(object sender, TextChangedEventArgs args)
        {
            requestButton.IsEnabled = bookIdTextBox.Text.Length > 0 &&
                    Int32.TryParse(bookIdTextBox.Text.Trim(' '), out bookID) &&
                    bookID > 0;
        }

        protected override void OnKeyUp(KeyEventArgs args)
        {
            if (args.Key == Key.Enter)
            {
                OnRequestButtonClick(this, args);
                args.Handled = true;
            }
            base.OnKeyUp(args);
        }

        void OnRequestButtonClick(object sender, RoutedEventArgs args)
        {
            StateDictionaryHelper.SafeRemove(PhoneApplicationService.Current.State, "downloadBook");
            EnableForSearch(false);
            statusTextBlock.Text = null;
            resultsPanel.Visibility = Visibility.Collapsed;
            catalogInfo.GutenbergBook = null;
            proxy.BookInfoAsync(bookID);
        }

        void OnCatalogServiceProxyBookInfoCompleted(object sender, BookInfoCompletedEventArgs args)
        {
            EnableForSearch(true);

            if (args.Cancelled)
            {
                statusTextBlock.Text = "Search was cancelled";
            }
            else if (args.Error != null)
            {
                statusTextBlock.Text = args.Error.Message;
            }
            else if (args.Result == null)
            {
                statusTextBlock.Text = "No book found with that ID number";
            }
            else
            {
                resultsPanel.Visibility = Visibility.Visible;
                scrollViewer.ScrollToBottom();
                catalogInfo.GutenbergBook = args.Result;
                EnableForSearch(true);
            }
        }

        void EnableForSearch(bool enable)
        {
            requestButton.IsEnabled = enable;
            bookIdTextBox.IsEnabled = enable;
            progressBar.Visibility = enable ? Visibility.Collapsed : Visibility.Visible;
            progressBar.IsIndeterminate = !enable;
        }

        void OnContinueButtonClick(object sender, RoutedEventArgs args)
        {
            GutenbergBook book = catalogInfo.GutenbergBook;
            StateDictionaryHelper.SafeAdd(PhoneApplicationService.Current.State, "downloadBook", book);
            (Application.Current.RootVisual as Frame).Navigate(new Uri("/DownloadBookPage.xaml", UriKind.Relative));
        }
    }
}
